==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S5013dc63aece5960aaf85662d6e4defb.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "sconfig.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S5013dc63aece5960aaf85662d6e4defb.h"

#include "S545833936c4079bf95b16d8fea1c7133.h"

#include "S69339366de6cc19b593990f5cc1196a6.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "Sc9fab33e9458412c527c3fe8a13ee37d.h"

#include "S34ddd2a7515eccb177b2b41c0576524a.h"

#if HAVE_TIME_H
 
#include <time.h>

#endif
 
#include <stdlib.h>

#ifndef WIN32
 
# include <unistd.h>

#endif
  Saca418ab700fd41fea0a83282df12687 *Sa7ad29e77b51199c1194b613ea1848dc(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sc7ab55c385ea800f44b02840bdd351a7, unsigned short Se6bef242686b43d0ef26955afbb4af84, 
bool Se3f1cfcbd2a7460ed4b71f1cadbe52aa, bool Se6d056471be39d6a77b99dcae00a07a4) { Saca418ab700fd41fea0a83282df12687 
*Sa91c825497686f4bb44fce2dd018f3d2; 
#ifdef macintosh
 if (Se3f1cfcbd2a7460ed4b71f1cadbe52aa) S64b16d9a25417444c349960e9c925b28(); Sa91c825497686f4bb44fce2dd018f3d2 
= new S9306f7b874c0902f0015f766b71c4b8b(S4d682ec4eed27c53849758bc13b6e179, Sc7ab55c385ea800f44b02840bdd351a7, 
Se6bef242686b43d0ef26955afbb4af84, Se6d056471be39d6a77b99dcae00a07a4); 
#else
 Sa91c825497686f4bb44fce2dd018f3d2 = new Se7cafe837716ad825eb224e3c733ff04(S4d682ec4eed27c53849758bc13b6e179, 
Sc7ab55c385ea800f44b02840bdd351a7, Se6bef242686b43d0ef26955afbb4af84, Se3f1cfcbd2a7460ed4b71f1cadbe52aa, 
Se6d056471be39d6a77b99dcae00a07a4); 
#endif
 return Sa91c825497686f4bb44fce2dd018f3d2; }   void Saca418ab700fd41fea0a83282df12687::Sc41e621207e40e1b74dc089657ddb7e1(const 
unsigned char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { 
unsigned long S6165bac5ae2badc2e1030ea3f58dc586 = 0; long Scca72adcd930b27bcd8fcf62ebae2058 = 0; time_t 
S5b2a579f62087d17d79ce59f3de5f6d1 = 0; while (S6165bac5ae2badc2e1030ea3f58dc586 < Sf5a8e923f8cd24b56b3bab32358cc58a) 
{ long Sae887c29c29f5ca22060dcb00e0fb057; Saf6c0c3c714d1f5ab0d299b2cbf50060(Sae887c29c29f5ca22060dcb00e0fb057 
= Scc7e96e085b9d6b3ef9a1c58a8b2e49a((const unsigned char *) S7f2db423a49b305459147332fb01cf87 + Scca72adcd930b27bcd8fcf62ebae2058, 
Sf5a8e923f8cd24b56b3bab32358cc58a - S6165bac5ae2badc2e1030ea3f58dc586)); if (Sae887c29c29f5ca22060dcb00e0fb057 
< 0) break; S6165bac5ae2badc2e1030ea3f58dc586 += Sae887c29c29f5ca22060dcb00e0fb057; Scca72adcd930b27bcd8fcf62ebae2058 
+= Sae887c29c29f5ca22060dcb00e0fb057;  if (Sae887c29c29f5ca22060dcb00e0fb057 == 0) {  if (S5b2a579f62087d17d79ce59f3de5f6d1 
== 0) S5b2a579f62087d17d79ce59f3de5f6d1 = time(NULL);  time_t Saebb8e92423705899db317553df6e80d = time(NULL); 
if (Saebb8e92423705899db317553df6e80d - S5b2a579f62087d17d79ce59f3de5f6d1 > 30) break;  Sc83b0030f821e2fe82e18be6797b312f(100, 
1);  }   else { S5b2a579f62087d17d79ce59f3de5f6d1 = 0; } } }   void Saca418ab700fd41fea0a83282df12687::Saa232ed3abb535265477aeb8a1284765(const 
S749d2b576e15d77f0d14f186077e9ace &S03c7c0ace395d80182db07ae2c30f034) { Saf6c0c3c714d1f5ab0d299b2cbf50060(Saa232ed3abb535265477aeb8a1284765(S03c7c0ace395d80182db07ae2c30f034.c_str())); 
} void Saca418ab700fd41fea0a83282df12687::Saa232ed3abb535265477aeb8a1284765(const char *S03c7c0ace395d80182db07ae2c30f034) 
{ Saf6c0c3c714d1f5ab0d299b2cbf50060(Sc41e621207e40e1b74dc089657ddb7e1((const unsigned char *) S03c7c0ace395d80182db07ae2c30f034, 
strlen(S03c7c0ace395d80182db07ae2c30f034))); }   S749d2b576e15d77f0d14f186077e9ace Saca418ab700fd41fea0a83282df12687::S7d1281511882961ba8fc1234a718820c(bool 
S165e6d21e0a2cc9ebb32ca05f90e0fa7) {  unsigned char S7f2db423a49b305459147332fb01cf87[1001]; unsigned 
long S1a86493fd40f54214c8481d8228993e9 = 0; while (1) { long Sd871906e18d7e876e6494103da4beebd; S54cc1693f0ae18c58225f0cdb9e17a3f(Sd871906e18d7e876e6494103da4beebd 
= S4e2021bf4cf7828bbbd067a23d0145ff(&(S7f2db423a49b305459147332fb01cf87[0]), 1000)); if (Sd871906e18d7e876e6494103da4beebd) 
{ S7f2db423a49b305459147332fb01cf87[Sd871906e18d7e876e6494103da4beebd] = 0; return S749d2b576e15d77f0d14f186077e9ace((char 
*) S7f2db423a49b305459147332fb01cf87); } if (!S165e6d21e0a2cc9ebb32ca05f90e0fa7) return ""; if (S00ce06fa9365b55a063506933582e5b0) 
return ""; S1a86493fd40f54214c8481d8228993e9++; if (S1a86493fd40f54214c8481d8228993e9 == 1000) return 
""; } }   S749d2b576e15d77f0d14f186077e9ace Saca418ab700fd41fea0a83282df12687::S3ec1295a8639dfb99306bff24400f81f(void) 
{  S749d2b576e15d77f0d14f186077e9ace S03c7c0ace395d80182db07ae2c30f034; char S4a8a08f09d37b73795649038408b5f33; 
unsigned long Sd871906e18d7e876e6494103da4beebd; unsigned long S1a86493fd40f54214c8481d8228993e9 = 0; 
while (true) {  S54cc1693f0ae18c58225f0cdb9e17a3f(Sd871906e18d7e876e6494103da4beebd = S4e2021bf4cf7828bbbd067a23d0145ff((unsigned 
char*) &S4a8a08f09d37b73795649038408b5f33, 1)); if (Sd871906e18d7e876e6494103da4beebd == 0) { if (S00ce06fa9365b55a063506933582e5b0) 
return S03c7c0ace395d80182db07ae2c30f034; S1a86493fd40f54214c8481d8228993e9++; if (S1a86493fd40f54214c8481d8228993e9 
== 10000) return S03c7c0ace395d80182db07ae2c30f034; continue; }  if (S4a8a08f09d37b73795649038408b5f33 
== '\n') {  if (S03c7c0ace395d80182db07ae2c30f034[S03c7c0ace395d80182db07ae2c30f034.length() - 1] == 
'\r') S03c7c0ace395d80182db07ae2c30f034 = S03c7c0ace395d80182db07ae2c30f034.substr(0, S03c7c0ace395d80182db07ae2c30f034.length() 
- 1); break; }   S03c7c0ace395d80182db07ae2c30f034 += S4a8a08f09d37b73795649038408b5f33; }  return S03c7c0ace395d80182db07ae2c30f034; 
}

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S5013dc63aece5960aaf85662d6e4defb.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "sconfig.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S5013dc63aece5960aaf85662d6e4defb.h"

#include "S545833936c4079bf95b16d8fea1c7133.h"

#include "S69339366de6cc19b593990f5cc1196a6.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "Sc9fab33e9458412c527c3fe8a13ee37d.h"

#include "S34ddd2a7515eccb177b2b41c0576524a.h"

#if HAVE_TIME_H
 
#include <time.h>

#endif
 
#include <stdlib.h>

#ifndef WIN32
 
# include <unistd.h>

#endif
  Saca418ab700fd41fea0a83282df12687 *Sa7ad29e77b51199c1194b613ea1848dc(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sc7ab55c385ea800f44b02840bdd351a7, unsigned short Se6bef242686b43d0ef26955afbb4af84, 
bool Se3f1cfcbd2a7460ed4b71f1cadbe52aa, bool Se6d056471be39d6a77b99dcae00a07a4) { Saca418ab700fd41fea0a83282df12687 
*Sa91c825497686f4bb44fce2dd018f3d2; 
#ifdef macintosh
 if (Se3f1cfcbd2a7460ed4b71f1cadbe52aa) S64b16d9a25417444c349960e9c925b28(); Sa91c825497686f4bb44fce2dd018f3d2 
= new S9306f7b874c0902f0015f766b71c4b8b(S4d682ec4eed27c53849758bc13b6e179, Sc7ab55c385ea800f44b02840bdd351a7, 
Se6bef242686b43d0ef26955afbb4af84, Se6d056471be39d6a77b99dcae00a07a4); 
#else
 Sa91c825497686f4bb44fce2dd018f3d2 = new Se7cafe837716ad825eb224e3c733ff04(S4d682ec4eed27c53849758bc13b6e179, 
Sc7ab55c385ea800f44b02840bdd351a7, Se6bef242686b43d0ef26955afbb4af84, Se3f1cfcbd2a7460ed4b71f1cadbe52aa, 
Se6d056471be39d6a77b99dcae00a07a4); 
#endif
 return Sa91c825497686f4bb44fce2dd018f3d2; }   void Saca418ab700fd41fea0a83282df12687::Sc41e621207e40e1b74dc089657ddb7e1(const 
unsigned char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { 
unsigned long S6165bac5ae2badc2e1030ea3f58dc586 = 0; long Scca72adcd930b27bcd8fcf62ebae2058 = 0; time_t 
S5b2a579f62087d17d79ce59f3de5f6d1 = 0; while (S6165bac5ae2badc2e1030ea3f58dc586 < Sf5a8e923f8cd24b56b3bab32358cc58a) 
{ long Sae887c29c29f5ca22060dcb00e0fb057; Saf6c0c3c714d1f5ab0d299b2cbf50060(Sae887c29c29f5ca22060dcb00e0fb057 
= Scc7e96e085b9d6b3ef9a1c58a8b2e49a((const unsigned char *) S7f2db423a49b305459147332fb01cf87 + Scca72adcd930b27bcd8fcf62ebae2058, 
Sf5a8e923f8cd24b56b3bab32358cc58a - S6165bac5ae2badc2e1030ea3f58dc586)); if (Sae887c29c29f5ca22060dcb00e0fb057 
< 0) break; S6165bac5ae2badc2e1030ea3f58dc586 += Sae887c29c29f5ca22060dcb00e0fb057; Scca72adcd930b27bcd8fcf62ebae2058 
+= Sae887c29c29f5ca22060dcb00e0fb057;  if (Sae887c29c29f5ca22060dcb00e0fb057 == 0) {  if (S5b2a579f62087d17d79ce59f3de5f6d1 
== 0) S5b2a579f62087d17d79ce59f3de5f6d1 = time(NULL);  time_t Saebb8e92423705899db317553df6e80d = time(NULL); 
if (Saebb8e92423705899db317553df6e80d - S5b2a579f62087d17d79ce59f3de5f6d1 > 30) break;  Sc83b0030f821e2fe82e18be6797b312f(100, 
1);  }   else { S5b2a579f62087d17d79ce59f3de5f6d1 = 0; } } }   void Saca418ab700fd41fea0a83282df12687::Saa232ed3abb535265477aeb8a1284765(const 
S749d2b576e15d77f0d14f186077e9ace &S03c7c0ace395d80182db07ae2c30f034) { Saf6c0c3c714d1f5ab0d299b2cbf50060(Saa232ed3abb535265477aeb8a1284765(S03c7c0ace395d80182db07ae2c30f034.c_str())); 
} void Saca418ab700fd41fea0a83282df12687::Saa232ed3abb535265477aeb8a1284765(const char *S03c7c0ace395d80182db07ae2c30f034) 
{ Saf6c0c3c714d1f5ab0d299b2cbf50060(Sc41e621207e40e1b74dc089657ddb7e1((const unsigned char *) S03c7c0ace395d80182db07ae2c30f034, 
strlen(S03c7c0ace395d80182db07ae2c30f034))); }   S749d2b576e15d77f0d14f186077e9ace Saca418ab700fd41fea0a83282df12687::S7d1281511882961ba8fc1234a718820c(bool 
S165e6d21e0a2cc9ebb32ca05f90e0fa7) { 
#define Sbebbed9d5d871c997fca4e84f53da6a2 10000
 unsigned char S7f2db423a49b305459147332fb01cf87[Sbebbed9d5d871c997fca4e84f53da6a2 + 1]; unsigned long 
S1a86493fd40f54214c8481d8228993e9 = 0; while (1) { long Sd871906e18d7e876e6494103da4beebd; S54cc1693f0ae18c58225f0cdb9e17a3f(Sd871906e18d7e876e6494103da4beebd 
= S4e2021bf4cf7828bbbd067a23d0145ff(&(S7f2db423a49b305459147332fb01cf87[0]), Sbebbed9d5d871c997fca4e84f53da6a2)); 
if (Sd871906e18d7e876e6494103da4beebd) { S7f2db423a49b305459147332fb01cf87[Sd871906e18d7e876e6494103da4beebd] 
= 0; return S749d2b576e15d77f0d14f186077e9ace((char *) S7f2db423a49b305459147332fb01cf87); } if (S00ce06fa9365b55a063506933582e5b0) 
return ""; if (!S165e6d21e0a2cc9ebb32ca05f90e0fa7) return ""; S1a86493fd40f54214c8481d8228993e9++; if 
(S1a86493fd40f54214c8481d8228993e9 == 1000) return ""; } }   S749d2b576e15d77f0d14f186077e9ace Saca418ab700fd41fea0a83282df12687::S3ec1295a8639dfb99306bff24400f81f(void) 
{  S749d2b576e15d77f0d14f186077e9ace S03c7c0ace395d80182db07ae2c30f034; char S4a8a08f09d37b73795649038408b5f33; 
unsigned long Sd871906e18d7e876e6494103da4beebd; unsigned long S1a86493fd40f54214c8481d8228993e9 = 0; 
while (true) {  S54cc1693f0ae18c58225f0cdb9e17a3f(Sd871906e18d7e876e6494103da4beebd = S4e2021bf4cf7828bbbd067a23d0145ff((unsigned 
char*) &S4a8a08f09d37b73795649038408b5f33, 1)); if (Sd871906e18d7e876e6494103da4beebd == 0) { if (S00ce06fa9365b55a063506933582e5b0) 
return S03c7c0ace395d80182db07ae2c30f034; S1a86493fd40f54214c8481d8228993e9++; if (S1a86493fd40f54214c8481d8228993e9 
== 10000) return S03c7c0ace395d80182db07ae2c30f034; continue; }  if (S4a8a08f09d37b73795649038408b5f33 
== '\n') {  if (S03c7c0ace395d80182db07ae2c30f034[S03c7c0ace395d80182db07ae2c30f034.length() - 1] == 
'\r') S03c7c0ace395d80182db07ae2c30f034 = S03c7c0ace395d80182db07ae2c30f034.substr(0, S03c7c0ace395d80182db07ae2c30f034.length() 
- 1); break; }   S03c7c0ace395d80182db07ae2c30f034 += S4a8a08f09d37b73795649038408b5f33; }  return S03c7c0ace395d80182db07ae2c30f034; 
}
